<?xml version='1.0'?>

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="2.0"
                xmlns:saxon="http://icl.com/saxon"
                extension-element-prefixes="saxon">

<!-- =============================================================== -->
<!--          Training to Slidy XSLT                                 -->
<!-- =============================================================== -->
<!--  This Training to Slidy XSLT has been developed to create       -->
<!--  take advantage of the W3C slidy presentation library and       -->
<!--  an XML presentation that has been authored in conformance with -->
<!--  the Training DTD.                                              -->
<!--  This XSLT has been tested with both IE and Firefox.            -->
<!-- =============================================================== -->
<!-- USE: Add the following line to your valid XML document after    -->
<!-- the XML declaration:                                            -->
<!--                                                                 -->
<!-- <?xml-stylesheet href="Training-to-slidy.xsl" type="text/xsl"?> -->
<!-- =============================================================== -->
<!--  No guarantees are provided with the use of the DTD.            -->
<!-- =============================================================== -->
<!-- If you have any questions please contact:                       -->
<!--                                                                 -->
<!-- Betty Harvey (harvey@eccnet.com) 410-787-9200                   -->
<!-- =============================================================== -->

<xsl:variable name="one">1</xsl:variable>
<xsl:variable name="number">1</xsl:variable>
     
<xsl:output method="html" indent="yes"></xsl:output>     

<xsl:template match="training-material">
     <html xmlns="http://www.w3.org/1999/xhtml" lang="en" xml:lang="en">
          <head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />
               <title><xsl:value-of select="//training-material/title"/> - 
                    <xsl:choose>
                         <xsl:when test="//authorinfo/author">
                              <xsl:value-of select="//authorinfo/author[1]"/>
                              and 
                              <xsl:value-of select="//authorinfo/author[2]"/>
                         </xsl:when>
                         <xsl:otherwise>
                              <xsl:value-of select="//authorinfo/name"/>
                         </xsl:otherwise>
                    </xsl:choose>
               </title>
             <!--  <meta name="copyright" content="Copyright © 2009 NARA" />-->
               <link rel="stylesheet" type="text/css" media="screen, projection" href="slidy/ecc_slidy.css" />
               <!--<link rel="stylesheet" type="text/css" media="screen, projection" href="slidy/dfc_slidy.css" />
               <link rel="stylesheet" type="text/css" media="screen, projection" href="slidy/w3c-blue.css" />
               <link rel="stylesheet" type="text/css" media="screen, projection, print" href="./xslidy.css" />-->
               <link rel="author">
               <xsl:attribute name="href"><xsl:value-of select="authorinfo/email"/></xsl:attribute>
               </link>
               <link rel="next" href="manual" title="Manual" />
               <link rel="last" href="tests" title="Tests" />
               <script type="text/javascript" src="slidy/slidy.js"></script>
               <style type="text/css">
          <!--.outlink:before { content : "↗ " ; }-->
          .elem:before { content : "\3c" ; }
          .elem:after { content : "\3e" ; }
          .pi:before { content : "\3c?" ; }
          .pi:after { content : "?\3e" ; }
          .key:before { content : open-quote ; }
          .key:after { content : close-quote ; }
               </style>
          </head>
          <body>
               <!--
               <div class="background">
          <img alt="" id="head-icon" src="slidy/icon-blue.png" />
          <object id="head-logo" data="slidy/w3c-logo-blue.svg" type="image/svg+xml" title="W3C logo">
               <a class="outlink" href="http://www.w3.org/" title="http://www.w3.org/">
                    <img alt="W3C logo" id="head-logo-fallback" src="slidy/w3c-logo-blue.gif" />
               </a>
          </object>
               </div>
               <div class="background slanty">
                    <img src="slidy/w3c-logo-slanted.jpg" alt="slanted W3C logo" />
               </div>-->
               <div class="slide cover" id="d106e1">
                    <img src="slidy/era-logo.jpg" alt="NARA ERA" class="cover"/>
                    <br clear="all" />
                    <h1 align="center">
                         <xsl:value-of select="title"/><br/>
                         <xsl:value-of select="presentation-info/conference-name"/><br/>
                         <xsl:call-template name="createAuthor"/>
      
                         <br/><br/>
                        Presentation Date: <xsl:value-of select="presentation-info/date"/>
                        
                        
                    </h1>
               </div>
<xsl:apply-templates/>
     </body>
          </html>
</xsl:template>
     
     <xsl:template name="createAuthor">
          <xsl:choose>
               <xsl:when test="//authorinfo/author">
                   <xsl:for-each select="//authorinfo/author">
                        <font color="#800000" size="6">
                        <br/><xsl:value-of select="name"/> <br/>
                         <xsl:value-of select="company"/><br/>
                        <a><xsl:attribute name="href">mailto:<xsl:value-of select="e-mail"/></xsl:attribute>
                             <xsl:value-of select="e-mail"/> </a>
                        <br/>
                        </font>
                   </xsl:for-each>
               </xsl:when>
               <xsl:otherwise>
                    <xsl:value-of select="authorinfo/name"/> <br/>
                    <a class="outlink">
                         <xsl:attribute name="href"><xsl:value-of select="//authorinfo/email"/></xsl:attribute>
                         <xsl:value-of select="//authorinfo/email"/></a><br/>
                    <xsl:value-of select="//authorinfo/company"/><br/>
               </xsl:otherwise>
          </xsl:choose>
     </xsl:template>

<xsl:template match="//training-material/title"/>

<xsl:template match="section">
     <div class="slide" id="{@id}" style="visibility: hidden; position: absolute;">
          <p/>
          <p/>
          <h1>Section <xsl:number count="//section"/>: <xsl:value-of select="title"/></h1>
          <xsl:if test="introduction">
               <h3>Introduction</h3>
              <xsl:for-each select="introduction/*">
                   <xsl:apply-templates/>
              </xsl:for-each>
          </xsl:if>
     </div>
     <xsl:apply-templates/>
</xsl:template>

<xsl:template match="section/introduction"/>

<xsl:template match="//section/title"/>




<xsl:template match="slide">
  <xsl:call-template name="createSlide"/>
</xsl:template>
     
     <xsl:template name="createSlide">
          <div class="slide" id="{@id}" style="visibility: hidden; position: absolute;">
               <h1><img src="slidy/era-logo.jpg" width="89px" height="72px"/>&#160;&#160;<xsl:value-of select="title"/></h1>
               <p class="sectionTOC"><font size="2"><b>Section</b>&#160; <xsl:number count="section"/>: <xsl:value-of select="ancestor::section/title"/></font></p>
               <xsl:apply-templates/>
              
          </div>
     </xsl:template>

<xsl:template match="slide/title"/>
    


<xsl:template match="slide/subtitle">
     <center>
     <font color="maroon" size="5"><xsl:apply-templates/></font>
     </center>
</xsl:template>

<xsl:template match="lab/title">
     <div class="slide" id="{@id}">
          <xsl:apply-templates/>
     </div>
</xsl:template>

<xsl:template match="introduction">
     <div class="slide" id="{@id}">
          <h1><img src="slidy/era-logo.jpg" width="89px" height="72px"/>&#160;&#160;Introduction</h1>
          <xsl:apply-templates/>  
          </div>
</xsl:template>

<xsl:template match="list">
	<ul><xsl:apply-templates/></ul>
</xsl:template>
     
<xsl:template match="list[@role='launch']">
     <span class="launch">
          <ul><xsl:apply-templates/></ul>
     </span>
</xsl:template>     

<xsl:template match="item">
	<li><xsl:apply-templates/></li>
</xsl:template>

<xsl:template match="list/header">
      <h4><xsl:apply-templates/></h4>
</xsl:template>
     
     <!--
<xsl:template match="para[@role='launch']">
     <span class="launch">
          <ul>
          <li><xsl:apply-templates/></li>
          </ul>
     </span>
</xsl:template>
 
-->
<xsl:template match="para">
    <p>
	<xsl:apply-templates/></p>
</xsl:template>

<xsl:template match="instructors-notes/para">
    <p><xsl:apply-templates/></p>
</xsl:template>

<xsl:template match="note">
    <p><font size="5"><font color="red">NOTE:  </font>
	<xsl:apply-templates/>
    </font></p>
</xsl:template>

<xsl:template match="emph">
   <font color="red"><xsl:apply-templates/></font>
</xsl:template>


     <xsl:template match="figure">
          <xsl:if test="caption">
               <h5 align="center"><xsl:value-of select="caption"/></h5>
          </xsl:if>
          <div style="margin-left: 4em; position: relative;">
               <xsl:for-each select="graphic">
                    <xsl:choose>
                         <xsl:when test="preceding-sibling::graphic">
                              <img style="position: absolute; left: 0pt; top: 0pt;" >
                                   <xsl:attribute name="src"><xsl:value-of select="@name"/></xsl:attribute>
                                   <xsl:attribute name="alt"><xsl:value-of select="@alt"/></xsl:attribute>
                                   <xsl:attribute name="width"><xsl:value-of select="@width"/></xsl:attribute>
                                   <xsl:attribute name="height"><xsl:value-of select="@height"/></xsl:attribute>
                              </img>
                         </xsl:when>
                         <xsl:otherwise>
                              <img  style="position: static; vertical-align: bottom;" >
                                   <xsl:attribute name="src"><xsl:value-of select="@name"/></xsl:attribute>
                                   <xsl:attribute name="alt"><xsl:value-of select="@alt"/></xsl:attribute>
                                   <xsl:attribute name="width"><xsl:value-of select="@width"/></xsl:attribute>
                                   <xsl:attribute name="height"><xsl:value-of select="@height"/></xsl:attribute>
                              </img>
                         </xsl:otherwise>
                    </xsl:choose>
                    <xsl:apply-templates/>
               </xsl:for-each>
          </div>
     </xsl:template>

<xsl:template match="caption"/>
     
    <xsl:template match="figure/graphic"/> 

<xsl:template match="example-grp/header">
     <h4 align="center"><xsl:apply-templates/></h4>
</xsl:template>
     
<xsl:template match="graphic">
          <img>
               <xsl:attribute name="src"><xsl:value-of select="@name"/></xsl:attribute>
               <xsl:attribute name="alt"><xsl:value-of select="@alt"/></xsl:attribute>
               <xsl:attribute name="width"><xsl:value-of select="@width"/></xsl:attribute>
               <xsl:attribute name="height"><xsl:value-of select="@height"/></xsl:attribute>
          </img><xsl:apply-templates/>
</xsl:template>     

<xsl:template match="figure/graphic[1]">
     <img style="position: static; vertical-align: bottom;" >
        <xsl:attribute name="src"><xsl:value-of select="@name"/></xsl:attribute>
	 <xsl:attribute name="alt"><xsl:value-of select="@alt"/></xsl:attribute>
          <xsl:attribute name="width"><xsl:value-of select="@width"/></xsl:attribute>
          <xsl:attribute name="height"><xsl:value-of select="@height"/></xsl:attribute>
      </img><xsl:apply-templates/>
</xsl:template>
     
     <xsl:template match="figure/graphic">
          <img  style="position: absolute; left: 0pt; top: 0pt;" >
               <xsl:attribute name="src"><xsl:value-of select="@name"/></xsl:attribute>
               <xsl:attribute name="alt"><xsl:value-of select="@alt"/></xsl:attribute>
               <xsl:attribute name="width"><xsl:value-of select="@width"/></xsl:attribute>
               <xsl:attribute name="height"><xsl:value-of select="@height"/></xsl:attribute>
          </img><xsl:apply-templates/>
     </xsl:template>    

<xsl:template match="multimedia">
      <p align="center"><a>
        <xsl:attribute name="href"><xsl:value-of select="@name"/></xsl:attribute>View Video
      </a></p>
</xsl:template>

<xsl:template match="graphic[@type='svg']">
      <center>
      <object>
          <xsl:attribute name="type">image/svg+xml</xsl:attribute>
	  <xsl:attribute name="data"><xsl:value-of select="@name"/></xsl:attribute>
	  <xsl:attribute name="width"><xsl:value-of select="@width"/></xsl:attribute>
	  <xsl:attribute name="height"><xsl:value-of select="@height"/></xsl:attribute>
          <img>
        <xsl:attribute name="src"><xsl:value-of select="@name"/></xsl:attribute>
	 <xsl:attribute name="alt"><xsl:value-of select="@alt"/></xsl:attribute>
      </img>
      </object><xsl:apply-templates/></center>
</xsl:template>

<xsl:template match="para/graphic[@type='svg']">
      <object>
          <xsl:attribute name="type">image/svg+xml</xsl:attribute>
	  <xsl:attribute name="data"><xsl:value-of select="@name"/></xsl:attribute>
	  <xsl:attribute name="width"><xsl:value-of select="@width"/></xsl:attribute>
	  <xsl:attribute name="height"><xsl:value-of select="@height"/></xsl:attribute>
          <img>
        <xsl:attribute name="src"><xsl:value-of select="@name"/></xsl:attribute>
	 <xsl:attribute name="alt"><xsl:value-of select="@alt"/></xsl:attribute>
      </img>
      </object><xsl:apply-templates/>
</xsl:template>

<xsl:template match="para/graphic">
       <img>
        <xsl:attribute name="src"><xsl:value-of select="@name"/></xsl:attribute>
	 <xsl:attribute name="alt"><xsl:value-of select="@alt"/></xsl:attribute>
      </img><xsl:apply-templates/>
</xsl:template>

<xsl:template match="/training-material/title">
     <h2 align="center"><xsl:apply-templates/></h2>
</xsl:template>

<xsl:template match="example">
     <pre><font color="maroon" size="3"><xsl:apply-templates/></font></pre>
</xsl:template>

<xsl:template match="table">
     <table align="left">
       <xsl:copy-of select="@*"/>
      <xsl:apply-templates/></table>
</xsl:template>

<xsl:template match="table/header">
      <h4 align="center"><xsl:apply-templates/></h4>
</xsl:template>

<xsl:template match="tr">
     <tr><xsl:apply-templates/></tr>
</xsl:template>

<xsl:template match="td">
     <td>
          <xsl:copy-of select="@*"/>
          <xsl:apply-templates/>
     </td>
          
</xsl:template>
     
     <xsl:template match="th">
          <th><xsl:apply-templates/>&#160;</th>
     </xsl:template>

<xsl:template match="b">
     <b><xsl:apply-templates/></b>
</xsl:template>

<xsl:template match="i">
     <i><xsl:apply-templates/></i>
</xsl:template>

<xsl:template match="url">
    <a>
       <xsl:attribute name="href"><xsl:value-of select="."/></xsl:attribute>
       <xsl:apply-templates/>
    </a>
</xsl:template>

<xsl:template match="xlink">
     <a target="_blank">
       <xsl:attribute name="href"><xsl:value-of select="@href"/></xsl:attribute>
       <xsl:apply-templates/>
    </a>
</xsl:template>
     
     <xsl:template match="instructors-notes"/>

<!--
<xsl:template match="instructors-notes">
    <xsl:variable name="file">instructor<xsl:number level="any" from="training-material"/>.html</xsl:variable>
    <xsl:variable name="slideno"><xsl:number level="any" from="training-material"/></xsl:variable>
         <table width="20%" align="right">
     <tr>
                <td align="center"><a>
           <xsl:attribute name="href">instructor<xsl:value-of select="$slideno"/>.html</xsl:attribute>
                <img src="..\graphics\help_btn.gif"/><br/>
           </a>
           </td>
     </tr>
     </table>
    <xsl:result-document href="{$file}">
        <html><head><title><xsl:value-of select="title"/></title></head>
         <body>
         <table align="center" valign="90%"><tr><td>
	<a><xsl:attribute name="name"><xsl:value-of select="@id"/></xsl:attribute></a>
	<xsl:apply-templates/>
        <p></p>
        <table align="center" width="50%">
        <tr>
           <td align="right"><a>
                <xsl:attribute name="href"><xsl:value-of select="$slideno"/>.html</xsl:attribute>
                <img src="..\graphics\prevbutton.gif"/><br/>Back to Slide.</a>
           </td>
        </tr>
        </table>
                

        </td></tr>
        </table>
        </body>
        </html>
    </xsl:result-document>
</xsl:template>
-->
     
<xsl:template match="lab">
   <xsl:call-template name="createSlide"/>
</xsl:template>

<xsl:template match="procedure">
    <h4><xsl:value-of select="header"/></h4>
    <ol><xsl:apply-templates/></ol>
</xsl:template>

<xsl:template match="procedure/header"/>

<xsl:template match="step">
     <li><xsl:apply-templates/></li>
</xsl:template>
     
     <xsl:template match="header">
          <h4 align="center"><xsl:apply-templates/></h4>
     </xsl:template>

<xsl:template match="step/para">
    <p><xsl:apply-templates/></p>
</xsl:template>

<xsl:template match="step/list">
    <ul><xsl:apply-templates/></ul>
</xsl:template>

<xsl:template match="step/list/item">
    <li><xsl:apply-templates/></li>
</xsl:template>

<xsl:template match="lab/para">
    <p><xsl:apply-templates/></p>
</xsl:template>

<xsl:template match="lab/list">
    <ul><xsl:apply-templates/></ul>
</xsl:template>

<xsl:template match="lab/list/item">
    <li><xsl:apply-templates/></li>
</xsl:template>

<xsl:template match="name">
     <h2 align="center"><xsl:apply-templates/></h2>
</xsl:template>

<xsl:template match="company">
     <h3 align="center"><xsl:apply-templates/></h3>
</xsl:template>

<xsl:template match="address">
   <h4 align="center"><xsl:apply-templates/></h4>
</xsl:template>

<xsl:template match="street">
     <xsl:apply-templates/><br/>
</xsl:template>

<xsl:template match="city">
     <xsl:apply-templates/>,
</xsl:template>

<xsl:template match="e-mail">
     <h4 align="center">
     <a>
	<xsl:attribute name="href">mailto:<xsl:value-of select="."/></xsl:attribute>
	<xsl:apply-templates/>
     </a>	
     </h4>
</xsl:template>

<xsl:template match="telephone">
     <h4 align="center"><xsl:apply-templates/></h4>
</xsl:template>

<xsl:template match="word">
     <i><b><xsl:apply-templates/></b></i><xsl:text>:  </xsl:text>
</xsl:template>

<xsl:template match="br">
     <br><xsl:apply-templates/></br>
</xsl:template>

<xsl:template match="presentation-info"/>
     <xsl:template match="date"/>
     <xsl:template match="authorinfo"/>

     
     <xsl:template match="quoted-block">
          <xsl:apply-templates/>
     </xsl:template>
     
     <xsl:template match="quoted-block/para">
          <p class="cite"><i><xsl:apply-templates/></i></p>
     </xsl:template>
     
     <xsl:template match="quoted-from">
          <p class="cite"><xsl:apply-templates/></p>
     </xsl:template>

<xsl:template match="deflist">
     <dl><xsl:apply-templates/></dl>
</xsl:template>
     
     <xsl:template match="termgrp">
          <xsl:apply-templates/>
     </xsl:template>
     
     <xsl:template match="term">
          <dt><xsl:apply-templates/></dt>
     </xsl:template>
     
     <xsl:template match="definition">
          <dd><xsl:apply-templates/></dd>
     </xsl:template>

</xsl:stylesheet>
